Learn R Programming

BeastJar (version 10.5.1)

BeastJar-package: BeastJar: JAR Dependency for MCMC Using 'BEAST'

Description

Provides JAR to perform Markov chain Monte Carlo (MCMC) inference using the popular Bayesian Evolutionary Analysis by Sampling Trees 'BEAST X' software library of Baele et al (2025) tools:::Rd_expr_doi("10.1038/s41592-025-02751-x"). 'BEAST X' supports auto-tuning Metropolis-Hastings, slice, Hamiltonian Monte Carlo and Sequential Monte Carlo sampling for a large variety of composable standard and phylogenetic statistical models using high performance computing. By placing the 'BEAST X' JAR in this package, we offer an efficient distribution system for 'BEAST X' use by other R packages using CRAN.

Arguments

Author

Maintainer: Marc A. Suchard msuchard@ucla.edu [copyright holder]

Other contributors:

  • Andrew Rambaut [copyright holder]

  • Alexei J. Drummond [copyright holder]

See Also